@@ -231,10 +231,13 @@ protected
 
 	def ignore_site_access?()
 		result = false;
-		ignore_list = site_property['ignore_sites'].split(",")
+		ignore_list = self.site_property['ignore_sites'].split(",")
 		ignore_list.each(){ |ignore_ip|
-			if Regexp.new(ignore_ip) =~ self.remote_address then
-				result = true;
+			begin
+				if Regexp.new(ignore_ip) =~ self.remote_address then
+					result = true;
+				end
+			rescue RegexpError
 			end
 		}
 		result
@@ -825,8 +828,8 @@ protected
 			admin_site_freeze()
 		end
 
-		theme_list = Dir.glob("#{self.theme_dir}/*/").sort().collect(){ |theme_dir|
-			theme_name = File.basename(File.dirname(theme_dir))
+		theme_list = Dir.glob("#{self.theme_dir}/*/*.css").sort().collect(){ |theme_css_file|
+			theme_name = File.basename(File.dirname(theme_css_file))
 			theme_data = { :theme_name => theme_name }
 			if theme_name == self.site_property['theme'] then
 				theme_data[:is_selected] = true
